"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __exportStar = (this && this.__exportStar) || function(m, exports) {
    for (var p in m) if (p !== "default" && !Object.prototype.hasOwnProperty.call(exports, p)) __createBinding(exports, m, p);
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.diff = void 0;
const fs = __importStar(require("node:fs/promises"));
const path = __importStar(require("node:path"));
const process = __importStar(require("node:process"));
const reporters_1 = require("./reporters");
const services_1 = require("./services");
const diff = async ({ filePatterns, outFile, auth, silent = false, reporters: reporterIds = ["gitlab-pr-note"], thresholds = {}, }) => {
    const env = (0, services_1.getEnv)();
    const cwd = process.cwd();
    const logger = (0, services_1.createLogger)({ silent });
    const gitlab = new services_1.GitLabAPI({
        services: {
            logger,
            http: services_1.http.createClient({
                headers: { "Private-Token": auth },
            }),
        },
    });
    const isPullRequest = Boolean(env.CI_MERGE_REQUEST_IID);
    const [current, last] = await Promise.all([
        (0, services_1.getFileStats)(filePatterns.map((pattern) => path.join(process.cwd(), pattern))),
        (async () => {
            if (!isPullRequest) {
                return [];
            }
            const job = await gitlab.getLatestPipelineJob({
                ref: "main",
                jobName: env.CI_JOB_NAME,
            });
            const artifacts = job?.id
                ? await gitlab.getJobArtifacts({ jobId: job?.id })
                : [];
            const artifact = artifacts.find((artifact) => artifact.name === outFile.replace("./", ""));
            return artifact?.contents;
        })(),
    ]);
    await fs.writeFile(path.join(cwd, outFile), JSON.stringify(current, null, 2), "utf-8");
    if (!isPullRequest) {
        logger.success(`Finished creating the last known file-size artifact.`);
        return [];
    }
    if (last) {
        logger.info(`Resolved last known file-size artifact, creating the change report...`);
    }
    else {
        logger.warn(`Unable to resolve last known file-size artifact, creating the initial change report...`);
    }
    const results = [
        ...current.map(({ path, bytes }) => {
            return (0, services_1.createDiff)({
                id: path,
                sizes: {
                    current: bytes,
                    last: last?.find((s) => s.path === path)?.bytes ?? 0,
                },
                threshold: thresholds.each
                    ? (0, services_1.parseReadableFileSize)(thresholds.each)
                    : null,
            });
        }),
        (0, services_1.createDiff)({
            id: "summary",
            sizes: {
                current: current.reduce((acc, stat) => acc + stat.bytes, 0),
                last: (last ?? []).reduce((acc, stat) => acc + stat.bytes, 0),
            },
            threshold: thresholds.overall
                ? (0, services_1.parseReadableFileSize)(thresholds.overall)
                : null,
        }),
    ];
    // Execute all reporters with the results
    const services = {
        env,
        gitlab,
        logger,
    };
    await Promise.all(reporterIds.map(async (reporterId) => {
        const reporter = reporters_1.reporters[reporterId];
        if (!reporter) {
            logger.warn(`Unable to resolve reporter "${reporterId}". Available values are "${Object.keys(reporters_1.reporters).join(", ")}".`);
            return;
        }
        try {
            await reporter(results, services);
        }
        catch (err) {
            logger.error(err, `Failed to execute reporter "${reporterId}".`);
        }
    }));
    logger.success(`Finished executing all reporters.`);
    logger.info(`Checking if all thresholds are met...`);
    // Conditionally fail the job if a threshold exceeded.
    const isThresholdMatched = results.every((result) => result.isBelowThreshold);
    if (isPullRequest && !isThresholdMatched) {
        throw new Error("One or more files do not meet the specified thresholds. See reporter output above for more details.");
    }
    logger.success(`Threshold are met, we are good to go! :-)`);
    return results;
};
exports.diff = diff;
__exportStar(require("./types"), exports);
