"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.createHttpMockAPI = void 0;
const services_1 = require("../services");
const createHttpMockAPI = () => {
    let mocks = [];
    return {
        mock: (mock) => {
            mocks.push(mock);
        },
        setup: () => {
            // @ts-expect-error
            jest.spyOn(services_1.http, "createClient").mockImplementation(() => {
                const requestCountByMethodAndUrl = {};
                return async (url, options) => {
                    const id = `${options.method} ${url}`;
                    const count = requestCountByMethodAndUrl[id] ?? 0;
                    const matches = mocks.filter((mock) => mock.url === url && mock.method === options.method);
                    const match = matches[count] ?? matches[0];
                    requestCountByMethodAndUrl[id]++;
                    if (!match) {
                        console.warn(`Unable to find http request mock for ${id}, did you forget to add the corresponding mock to your test suite?`);
                    }
                    return {
                        statusCode: match?.statusCode ?? 200,
                        body: (match?.body ?? null),
                    };
                };
            });
        },
        teardown: () => {
            mocks = [];
        },
    };
};
exports.createHttpMockAPI = createHttpMockAPI;
