"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const mocks_1 = require("../../mocks");
const services_1 = require("../../services");
const index_1 = require("./index");
describe("reporters['stdout']()", () => {
    const http = (0, mocks_1.createHttpMockAPI)();
    const env = (0, mocks_1.createEnvMockAPI)();
    let results = [];
    let services;
    beforeEach(async () => {
        const logger = (0, services_1.createLogger)({ silent: true });
        env.setup();
        http.setup();
        services = {
            gitlab: new services_1.GitLabAPI({
                services: { logger, http: services_1.http.createClient({}) },
            }),
            logger,
            env: (0, services_1.getEnv)(),
        };
        results = [
            {
                id: "src/mocks/files/normalize.css",
                status: "added",
                change: { raw: 6251, pretty: "+6.1 KB", percent: 100 },
                size: { raw: 6251, pretty: "6.1 KB" },
                isBelowThreshold: true,
            },
            {
                id: "src/mocks/files/normalize.css.zip",
                status: "added",
                change: { raw: 1941, pretty: "+1.9 KB", percent: 100 },
                size: { raw: 1941, pretty: "1.9 KB" },
                isBelowThreshold: true,
            },
            {
                id: "summary",
                status: "added",
                change: { raw: 8192, pretty: "+8 KB", percent: 100 },
                size: { raw: 8192, pretty: "8 KB" },
                isBelowThreshold: true,
            },
        ];
    });
    afterEach(async () => {
        env.teardown();
        http.teardown();
    });
    it("should log the results to the process output", async () => {
        const log = jest.spyOn(console, "log");
        await (0, index_1.stdout)(results, services);
        expect(log).toHaveBeenCalledWith(results);
    });
});
