"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.createDiff = void 0;
const file_1 = require("../file");
const createDiff = ({ id, sizes, threshold, }) => {
    const change = sizes.current - sizes.last;
    const hasChange = change !== 0;
    const hasIncrease = change > 0;
    let isBelowThreshold = true;
    let changeInPercent = "0";
    let status = "unchanged";
    if (sizes.last) {
        if (hasChange) {
            if (hasIncrease) {
                status = "increased";
            }
            else {
                status = "decreased";
            }
            changeInPercent = Math.abs(((sizes.last - sizes.current) / sizes.last) * 100.0).toFixed(2);
        }
    }
    else {
        status = "added";
        changeInPercent = "100";
    }
    if (threshold) {
        isBelowThreshold = sizes.current <= threshold;
    }
    const prefix = hasChange ? (hasIncrease ? "+" : "-") : "";
    return {
        id,
        status,
        change: {
            raw: change,
            pretty: `${prefix}${(0, file_1.getReadableFileSize)(Math.abs(change))}`,
            percent: parseFloat(changeInPercent),
        },
        size: {
            raw: sizes.current,
            pretty: (0, file_1.getReadableFileSize)(sizes.current),
        },
        isBelowThreshold,
    };
};
exports.createDiff = createDiff;
