"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.parseReadableFileSize = exports.getReadableFileSize = exports.getFileStats = void 0;
const fast_glob_1 = __importDefault(require("fast-glob"));
const fs = __importStar(require("node:fs/promises"));
const process = __importStar(require("node:process"));
const gzip = __importStar(require("gzip-size"));
const getFileStats = async (filepPatterns) => {
    const paths = await (0, fast_glob_1.default)(filepPatterns);
    const stats = await Promise.all(paths.map(async (path) => {
        const isCompressed = path.endsWith(".zip") || path.endsWith(".tar.gz");
        const relativePath = path.replace(process.cwd() + "/", "");
        if (!isCompressed) {
            return {
                path: relativePath,
                bytes: await gzip.file(path),
            };
        }
        const stat = await fs.stat(path);
        return {
            path: relativePath,
            bytes: stat.size,
        };
    }));
    return stats.sort((a, b) => a.path.localeCompare(b.path));
};
exports.getFileStats = getFileStats;
const k = 1024;
const sizes = ["Bytes", "KB", "MB", "GB", "TB", "PB", "EB", "ZB", "YB"];
const getReadableFileSize = (bytes, decimals = 2) => {
    if (!+bytes)
        return "0 Bytes";
    let isNegative = bytes < 0;
    bytes = Math.abs(bytes);
    const dm = decimals < 0 ? 0 : decimals;
    const index = Math.floor(Math.log(bytes) / Math.log(k));
    let pretty = "";
    pretty += `${parseFloat((bytes / Math.pow(k, index)).toFixed(dm))}`;
    pretty += ` `;
    pretty += `${sizes[index]}`;
    if (isNegative) {
        pretty = `-${pretty}`;
    }
    return pretty;
};
exports.getReadableFileSize = getReadableFileSize;
const parseReadableFileSize = (str) => {
    const size = sizes.find((size) => str.toLowerCase().endsWith(size.toLowerCase()));
    const index = sizes.indexOf(size ?? "");
    const float = parseFloat(str.replaceAll(" ", "").replace(new RegExp(size ?? "", "gim"), ""));
    if (index === -1 || Number.isNaN(float)) {
        throw new Error(`Unable to detect size for "${str}"`);
    }
    return float * Math.pow(k, index);
};
exports.parseReadableFileSize = parseReadableFileSize;
