import type { HttpClient } from "../http";
import type { Logger } from "../logger";
import type { MergeRequestNote, Pipeline, PipelineJob } from "./types";
declare type Dependencies = {
    logger: Logger;
    http: HttpClient;
};
declare class GitLabAPI {
    private readonly services;
    private readonly env;
    constructor({ services }: {
        services: Dependencies;
    });
    getLatestPipelineJob({ ref, jobName, }: {
        ref: string;
        jobName: string;
    }): Promise<PipelineJob | null>;
    getPipelinesForRef({ ref }: {
        ref: string;
    }): Promise<Pipeline[]>;
    getPipelineJobs({ pipelineId }: {
        pipelineId: number;
    }): Promise<PipelineJob[]>;
    getPipelineJob({ jobId }: {
        jobId: number;
    }): Promise<PipelineJob | null>;
    getJobArtifacts({ jobId }: {
        jobId: number;
    }): Promise<{
        name: string;
        contents: any;
    }[]>;
    getPullRequestComments({ mergeRequestIid, }: {
        mergeRequestIid: number;
    }): Promise<MergeRequestNote[]>;
    createPullRequestComment({ mergeRequestIid, comment, }: {
        mergeRequestIid: number;
        comment: string;
    }): Promise<void>;
    modifyPullRequestComment({ mergeRequestIid, commentId, comment, }: {
        mergeRequestIid: number;
        commentId: number;
        comment: string;
    }): Promise<void>;
}
export { GitLabAPI };
